Calculate daily error using one of three metrics, and also return coverage of credible intervals. Uses continuous ranked probability score (CRPS), mean absolute error and median absolute error.
posterior_metrics(object, type, newdata = NULL, groups = NULL, metrics = NULL)A fitted model object returned by epim.
See epimodel-objects.
A string specifying the name of the observations to plot. This should match one
of the names of the response variables in the obs argument used int the call to epim.
If provided, the original data used
in object is overridden. Useful for forecasting
Either NULL or a character vector specifying the groups
to plot for. Default is NULL, which plots all modeled groups.
A string or character vector specifying the plotted
forecast error metrics. One of NULL, "crps",
"mean_abs_error"
A dataframe giving forecast error for each metric and observation