Provides a summary of parameter estimates and MCMC diagnostics. Similar
to summary.stanreg in rstanarm.
# S3 method for epimodel
summary(
object,
pars = NULL,
regex_pars = NULL,
probs = c(0.1, 0.5, 0.9),
...,
digits = 1
)# S3 method for summary.epimodel
print(x, digits = max(1, attr(x, "print.digits")), ...)
A fitted model object returned by epim.
See epimodel-objects.
A character vector giving a subset of parameters to include. Default is NULL, in which case all parameters are included.
A character vector of regular expressions to select parameters. If pars is also used, regex_pars is used in conjunction with pars.
A numeric vector of probabilities for computing quantiles of parameter estimates.
Not used.
Number of digits to use for formatting numbers when printing.
An object of class "summary.epimodel".
An object of class "summary.epimodel".